@@ -2,8 +2,6 @@ import os
 import pickle
 import uuid
 
-import six
-
 from dagster import (
     AssetMaterialization,
     ExpectationResult,
@@ -37,7 +35,7 @@ from .serialize import PICKLE_PROTOCOL, read_value, write_value
 
 
 class DagstermillResourceEventGenerationManager(EventGenerationManager):
-    """ Utility class to explicitly manage setup/teardown of resource events. Overrides the default
+    """Utility class to explicitly manage setup/teardown of resource events. Overrides the default
     `generate_teardown_events` method so that teardown is deferred until explicitly called by the
     dagstermill Manager
     """
@@ -54,7 +52,7 @@ class DagstermillResourceEventGenerationManager(EventGenerationManager):
         ]
 
 
-class Manager(object):
+class Manager:
     def __init__(self):
         self.pipeline = None
         self.solid_def = None
@@ -64,7 +62,14 @@ class Manager(object):
         self.resource_manager = None
 
     def _setup_resources(
-        self, execution_plan, environment_config, pipeline_run, log_manager, resource_keys_to_init
+        self,
+        execution_plan,
+        environment_config,
+        pipeline_run,
+        log_manager,
+        resource_keys_to_init,
+        instance,
+        resource_instances_to_override,
     ):
         """
         Drop-in replacement for
@@ -72,7 +77,13 @@ class Manager(object):
         `DagstermillResourceEventGenerationManager` and explicitly calls `teardown` on it
         """
         generator = resource_initialization_event_generator(
-            execution_plan, environment_config, pipeline_run, log_manager, resource_keys_to_init
+            execution_plan,
+            environment_config,
+            pipeline_run,
+            log_manager,
+            resource_keys_to_init,
+            instance,
+            resource_instances_to_override,
         )
         self.resource_manager = DagstermillResourceEventGenerationManager(
             generator, ScopedResourcesBuilder
@@ -115,12 +126,9 @@ class Manager(object):
             instance_ref = unpack_value(instance_ref_dict)
             instance = DagsterInstance.from_ref(instance_ref)
         except Exception as err:  # pylint: disable=broad-except
-            six.raise_from(
-                DagstermillError(
-                    "Error when attempting to resolve DagsterInstance from serialized InstanceRef"
-                ),
-                err,
-            )
+            raise DagstermillError(
+                "Error when attempting to resolve DagsterInstance from serialized InstanceRef"
+            ) from err
 
         pipeline_run = unpack_value(pipeline_run_dict)
 
@@ -153,7 +161,6 @@ class Manager(object):
                 solid_config=run_config.get("solids", {}).get(solid_def.name, {}).get("config"),
                 resource_keys_to_init=get_required_resource_keys_to_init(
                     execution_plan,
-                    pipeline_context.system_storage_def,
                     pipeline_context.intermediate_storage_def,
                 ),
                 solid_name=solid_def.name,
@@ -237,7 +244,6 @@ class Manager(object):
                 solid_config=solid_config,
                 resource_keys_to_init=get_required_resource_keys_to_init(
                     execution_plan,
-                    pipeline_context.system_storage_def,
                     pipeline_context.intermediate_storage_def,
                 ),
                 solid_name=solid_def.name,
@@ -262,14 +268,13 @@ class Manager(object):
 
         if not self.solid_def.has_output(output_name):
             raise DagstermillError(
-                "Solid {solid_name} does not have output named {output_name}".format(
-                    solid_name=self.solid_def.name, output_name=output_name
-                )
+                f"Solid {self.solid_def.name} does not have output named {output_name}."
+                f"Expected one of {[str(output_def.name) for output_def in self.solid_def.output_defs]}"
             )
 
         dagster_type = self.solid_def.output_def_named(output_name).dagster_type
 
-        out_file = os.path.join(self.marshal_dir, "output-{}".format(output_name))
+        out_file = os.path.join(self.marshal_dir, f"output-{output_name}")
         scrapbook.glue(output_name, write_value(dagster_type, value, out_file))
 
     def yield_event(self, dagster_event):
